==> RsFsw-5.20.1.tar.gz: RsFsw-5.20.1/RsFsw/Implementations/Applications/K14x_Nr5G/Sense/Power/Achannel/Spacing/Gap/Auto.py <==
from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, spacing: float, gapChannel=repcap.GapChannel.Default) -> None:
		"""SCPI: [SENSe]:POWer:ACHannel:SPACing:GAP<gap>[:AUTO] \n
		Snippet: driver.applications.k14Xnr5G.sense.power.achannel.spacing.gap.auto.set(spacing = 1.0, gapChannel = repcap.GapChannel.Default) \n
		No command help available \n
			:param spacing: No help available
			:param gapChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Gap')
		"""
		param = Conversions.decimal_value_to_str(spacing)
		gapChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(gapChannel, repcap.GapChannel)
		self._core.io.write(f'SENSe:POWer:ACHannel:SPACing:GAP{gapChannel_cmd_val}:AUTO {param}')

	def get(self, gapChannel=repcap.GapChannel.Default) -> float:
		"""SCPI: [SENSe]:POWer:ACHannel:SPACing:GAP<gap>[:AUTO] \n
		Snippet: value: float = driver.applications.k14Xnr5G.sense.power.achannel.spacing.gap.auto.get(gapChannel = repcap.GapChannel.Default) \n
		No command help available \n
			:param gapChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Gap')
			:return: spacing: No help available"""
		gapChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(gapChannel, repcap.GapChannel)
		response = self._core.io.query_str(f'SENSe:POWer:ACHannel:SPACing:GAP{gapChannel_cmd_val}:AUTO?')
		return Conversions.str_to_float(response)

==> RsFsw-6.0.0.tar.gz: RsFsw-6.0.0/RsFsw/Implementations/Applications/K14x_Nr5G/Sense/Power/Achannel/Spacing/Gap/Auto.py <==
from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, spacing: float, gapChannel=repcap.GapChannel.Default) -> None:
		"""SCPI: [SENSe]:POWer:ACHannel:SPACing:GAP<gap>[:AUTO] \n
		Snippet: driver.applications.k14Xnr5G.sense.power.achannel.spacing.gap.auto.set(spacing = 1.0, gapChannel = repcap.GapChannel.Default) \n
		Defines the distance from sub block to the specified gap channel. In 'Auto' gap mode, channels in the upper gap are
		identical to those in the lower gap. Thus, only 2 gap channels are configured. The spacing for gap channels is defined in
		relation to the outer edges of the surrounding sub blocks, i.e. Spacing = [CF of the gap channel] - [left sub block
		center] + ([RF bandwidth of left sub block] /2) (See also Figure 'MSR signal structure' and Figure 'Sub block definition'.
		) \n
			:param spacing: numeric value in Hz Unit: HZ
			:param gapChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Gap')
		"""
		param = Conversions.decimal_value_to_str(spacing)
		gapChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(gapChannel, repcap.GapChannel)
		self._core.io.write(f'SENSe:POWer:ACHannel:SPACing:GAP{gapChannel_cmd_val}:AUTO {param}')

	def get(self, gapChannel=repcap.GapChannel.Default) -> float:
		"""SCPI: [SENSe]:POWer:ACHannel:SPACing:GAP<gap>[:AUTO] \n
		Snippet: value: float = driver.applications.k14Xnr5G.sense.power.achannel.spacing.gap.auto.get(gapChannel = repcap.GapChannel.Default) \n
		Defines the distance from sub block to the specified gap channel. In 'Auto' gap mode, channels in the upper gap are
		identical to those in the lower gap. Thus, only 2 gap channels are configured. The spacing for gap channels is defined in
		relation to the outer edges of the surrounding sub blocks, i.e. Spacing = [CF of the gap channel] - [left sub block
		center] + ([RF bandwidth of left sub block] /2) (See also Figure 'MSR signal structure' and Figure 'Sub block definition'.
		) \n
			:param gapChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Gap')
			:return: spacing: numeric value in Hz Unit: HZ"""
		gapChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(gapChannel, repcap.GapChannel)
		response = self._core.io.query_str(f'SENSe:POWer:ACHannel:SPACing:GAP{gapChannel_cmd_val}:AUTO?')
		return Conversions.str_to_float(response)
